@@ -1,6 +1,8 @@
 import centinel.utils.http as http
 
-class HTTPRequestExperiment:
+from centinel.experiment import Experiment
+
+class HTTPRequestExperiment(Experiment):
     name = "http_request"
 
     def __init__(self, input_file):
