@@ -1,6 +1,8 @@
 import socket
 
-class TCPConnectExperiment:
+from centinel.experiment import Experiment
+
+class TCPConnectExperiment(Experiment):
     name = "tcp_connect"
 
     def __init__(self, input_file):
