@@ -1,10 +1,12 @@
 import centinel.utils.http as http
 import centinel.utils.dnslib as dns
 
+from centinel.experiment import Experiment
+
 GOOGLE_DNS     = "8.8.8.8"
 SEARCH_STRING  = "home network testbed will appear at"
 
-class TurkeyExperiment:
+class TurkeyExperiment(Experiment):
     name = "turkey"
 
     def __init__(self, input_file):
@@ -32,10 +34,15 @@ class TurkeyExperiment:
             "Host" : self.host
         }
 
-        result = http.get_request(ip, self.path, headers, ssl=True)
+        blocked = True
 
-        blocked = SEARCH_STRING not in result["response"]["body"]
-        result["blocked"] = blocked
+        try:
+            result = http.get_request(ip, self.path, headers, ssl=True)
+
+            blocked = SEARCH_STRING not in result["response"]["body"]
+            result["blocked"] = blocked
+        except Exception as err:
+            result["blocked"] = str(err)
 
         self.results.append(result)
 
